onto2nx
=======

|develop_build| |develop_coverage| |python_versions| |pypi_version| |pypi_license|


.. |develop_build| image:: https://travis-ci.org/cthoyt/onto2nx.svg?branch=develop
    :target: https://travis-ci.org/cthoyt/onto2nx
    :alt: Build Status

.. |develop_coverage| image:: https://codecov.io/gh/cthoyt/onto2nx/coverage.svg?branch=develop
    :target: https://codecov.io/gh/cthoyt/onto2nx?branch=develop
    :alt: Code coverage Status

.. |python_versions| image:: https://img.shields.io/pypi/pyversions/onto2nx.svg
    :alt: Supported Python Versions
	
.. |pypi_version| image:: https://img.shields.io/pypi/v/onto2nx.svg
    :alt: Current version on PyPI

.. |pypi_license| image:: https://img.shields.io/pypi/l/onto2nx.svg
    :alt: GPL 3.0 License


Converts OWL ontologies and OBO to NetworkX Graphs

As of its first version, onto2nx currently relies on the code of a stripped-down version of OntoSpy. We'd
like to thank `Michele Pasin <https://github.com/lambdamusic>`_ for all of his hard work and making
it avaliable under GPL 3.0 so we could use it too.
